@@ -767,6 +767,8 @@ class regexp(object):
         :rtype: bool
 
         .. versionadded: 0.9.6"""
+        if issubclass(type(other), fa.OFA):
+            return other.equivalentP(self)
         return self.compare(other)
 
     def compareMinimalDFA(self, r, nfa_method="nfaPosition"):
@@ -785,6 +787,12 @@ class regexp(object):
 
         return self.wordDerivative(word).ewp()
 
+    def reversal(self):
+        """
+            Reversal of regexp
+        :rtype: regexp"""
+        return self.__copy__()
+
 
 class specialConstant(regexp):
     """Base class for Epsilon and EmptySet
@@ -900,6 +908,11 @@ class specialConstant(regexp):
         :return:"""
         return set()
 
+    def reversal(self):
+        """
+            Reversal of regexp
+        :rtype: regexp"""
+        return self.__copy__()
 
 class epsilon(specialConstant):
     """Class that represents the empty word.
@@ -1298,6 +1311,11 @@ class disj(connective):
         self.arg1._nfaFollowEpsilonStep(conditions)
         self.arg2._nfaFollowEpsilonStep(conditions)
 
+    def reversal(self):
+        """
+            Reversal of regexp
+        :rtype: regexp"""
+        return disj(self.arg1.reversal(), self.arg2.reversal(), sigma=self.Sigma)
 
 class power(regexp):
     """Class for power operation  on regular expressions.
@@ -1323,6 +1341,12 @@ class power(regexp):
     def setOfSymbols(self):
         return self.arg.setOfSymbols()
 
+    def reversal(self):
+        """
+            Reversal of regexp
+        :rtype: regexp"""
+        return power(self.arg.reversal(), self.pw, self.Sigma)
+
 
 class star(regexp):
     """Class for iteration operation (aka Kleene star, or Kleene closure) on regular expressions.
@@ -1534,6 +1558,12 @@ class star(regexp):
             nfa.addTransition(initial, Epsilon, iter_state)
             nfa.addTransition(iter_state, Epsilon, final)
 
+    def reversal(self):
+        """
+            Reversal of regexp
+        :rtype: regexp"""
+        return star(self.arg.reversal(), sigma=self.Sigma)
+
 
 class concat(connective):
     """Class for catenation operation on regular expressions.
@@ -1732,6 +1762,12 @@ class concat(connective):
         if target is not None:
             nfa.mergeStates(target, interm)
 
+    def reversal(self):
+        """
+            Reversal of regexp
+        :rtype: regexp"""
+        return concat(self.arg2.reversal(), self.arg1.reversal(), sigma=self.Sigma)
+
 
 class position(regexp):
     """Class for marked regular expression symbols.
